@@ -50,9 +50,8 @@ setup(
     zip_safe=True,
     include_package_data=True,
     classifiers=[
-        'Development Status :: 4 - Beta',
+        'Development Status :: 5 - Production/Stable',
         'Intended Audience :: Developers',
-        'Programming Language :: Python :: 2.7',
         'Programming Language :: Python :: 3.7',
         'Operating System :: OS Independent'
     ],
