@@ -5,7 +5,7 @@ import os
 import re
 from abc import ABCMeta, abstractmethod
 
-from sumoappclient.omnistorage.factory import ProviderFactory
+from sumoappclient.provider.factory import ProviderFactory
 from sumoappclient.common.logger import get_logger
 from sumoapputils.common.testapp import TestApp
 from sumoapputils.common.utils import get_file_data, USER, get_app_config_key
@@ -170,7 +170,7 @@ class BaseSubstitutionStrategy(object):
         if TestApp.is_mew_board(dash):
             panels = dash["rootPanel"].get("panels", []) if dash.get("rootPanel") else dash.get("panels", [])
             for panel in panels:
-                if panel.get("panelType") == "TextPanel" or panel.get("Type") == "TextPanel":
+                if panel.get("panelType") in ("TextPanel", "EventsOfInterestScatterPanel") or panel.get("Type") == "TextPanel":
                     continue
                 for query in panel["queries"]:
                     panel_name = panel.get("title")
@@ -182,10 +182,12 @@ class BaseSubstitutionStrategy(object):
             variables = dash["rootPanel"].get("variables", []) if dash.get("rootPanel") else dash.get("variables", [])
 
             for variable in variables:
-                if variable.get("sourceDefinition", {}).get("variableSourceType", "") == "LogQueryVariableSourceDefinition":
-                    variable["sourceDefinition"]["query"] = callback(variable["sourceDefinition"]["query"], "Variable: %s" % variable["name"], "Logs")
-                elif variable.get("sourceDefinition", {}).get("variableSourceType", "") == "MetricQueryVariableSourceDefinition":
-                    variable["sourceDefinition"]["query"] = callback(variable["sourceDefinition"]["query"], "Variable: %s" % variable["name"], "Metrics")
+                var_name = variable.get("name")
+                definition = variable.get("sourceDefinition", {})
+                if definition.get("variableSourceType", "") == "LogQueryVariableSourceDefinition":
+                    definition["query"] = callback(definition["query"], "Variable: %s" % var_name, "Logs")
+                elif definition.get("variableSourceType", "") == "MetadataVariableSourceDefinition":
+                    definition["filter"] = callback(definition["filter"], "Variable: %s" % var_name, "Metrics")
 
         else:
             for panel in dash["panels"]:
