@@ -1,5 +1,7 @@
 import copy
 import json
+import csv
+import xml.etree.ElementTree as ET
 import unittest
 import requests
 import six
@@ -8,7 +10,7 @@ import re
 from PIL import Image
 from functools import reduce
 from abc import abstractmethod, ABCMeta
-from sumoappclient.omnistorage.factory import ProviderFactory
+from sumoappclient.provider.factory import ProviderFactory
 from sumoapputils.common.utils import EXCLUDED_APPS_WITHOUT_SC_PARAMS, get_test_logger, slugify
 
 logger = get_test_logger()
@@ -26,6 +28,7 @@ class TestApp(unittest.TestCase):
 
     COMMUNITY_URL = "https://support.sumologic.com/hc/en-us/community/topics/200263058-Applications-and-Integrations"
     MAX_FILE_SIZE = 5*1000*1000
+    MIN_LOG_FILE_SIZE = 1000
     CUMULATIVE_MAX_FILE_SIZE = 100*1000*1000
     datetime_terms = ["week", "previous_week", "month", "previous_month", "relative", "RelativeTimeRangeBoundary", "yesterday", "today"]
 
@@ -75,7 +78,7 @@ class TestApp(unittest.TestCase):
             if self.is_mew_board(dash):
                 panels = dash["rootPanel"]["panels"] if dash.get("rootPanel") else dash.get("panels", [])
                 for panel in panels:
-                    if panel.get("panelType") == "TextPanel" or panel.get("Type") == "TextPanel":
+                    if panel.get("panelType") in ("TextPanel", "EventsOfInterestScatterPanel") or panel.get("Type") == "TextPanel":
                         continue
                     for query in panel["queries"]:
                         panel_name = panel.get("title")
@@ -231,10 +234,10 @@ class TestApp(unittest.TestCase):
             msg = "Following dashboards %s should follow <appname> - <dashboard title>" % ",".join(err)
             self.add_warning(msg)
 
-
     def test_version_preview_consistent(self):
         if self.app_preview_status:
-            self.assertTrue(self.app_version == "BETA", "App version should be BETA")
+            if not self.app_version == "BETA":
+                self.add_warning("App version should be BETA")
         else:
             self.assertTrue(float(self.app_version) > 0, "App version should be > 0")
 
@@ -248,11 +251,11 @@ class TestApp(unittest.TestCase):
         app_dir = os.path.dirname(self.appfile)
         # folder exists
         resource_folder = os.path.join(app_dir, "resources")
-        self.assertTrue(os.path.isdir(resource_folder))
+        self.assertTrue(os.path.isdir(resource_folder), "no resources folder: %s found" % resource_folder)
 
         for folder_name in ["logs", "icon", "screenshots"]:
             folder = os.path.join(resource_folder, folder_name)
-            self.assertTrue(os.path.isdir(folder))
+            self.assertTrue(os.path.isdir(folder), "%s folder does not exists" % folder)
 
             if folder_name in ["icon", "screenshots"] and os.listdir(folder) == 0:
                 self.add_warning("%s folder is empty" % folder_name)
@@ -282,11 +285,44 @@ class TestApp(unittest.TestCase):
                     logger.info("ImageName: %s Width: %s Height: %s" % (filename, width, height))
                     self.assertTrue(width == 72 and height == 72, "App Icon dimension should be 72x72")
                 elif parent_dir == "logs":
-                    self.assertTrue(filesize < 2*self.MAX_FILE_SIZE)
+                    self.assertTrue(filesize <= 2*self.MAX_FILE_SIZE, "%s exceeds 10 MB limit" % filepath)
+                    self.assertTrue(filesize > 0, "%s should not be empty" % filepath)
+                    if (filesize <= self.MIN_LOG_FILE_SIZE):
+                        self.add_warning("%s should be > 1KB and < 10 MB" % filepath)
+                    self.assertTrue(self.validate_format(filepath), "Only .txt, .csv, .xml, .json file formats are allowed")
                 file_size_sum += filesize
 
         self.assertTrue(file_size_sum < self.CUMULATIVE_MAX_FILE_SIZE)
 
+    def validate_format(self, filepath):
+        _, file_extension = os.path.splitext(filepath)
+        with open(filepath, 'r') as fp:
+            try:
+                if file_extension == ".csv":
+                    csv.reader(fp)
+                    logger.info("%s is a valid %s logfile" % (filepath, file_extension))
+                elif file_extension == ".json":
+                    try:
+                        # whole file is a valid json
+                        json.load(fp)
+                    except:
+                        # each line in the file is a valid json
+                        json.loads(fp.readline())
+                    logger.info("%s is a valid %s logfile" % (filepath, file_extension))
+                elif file_extension == ".xml":
+                    ET.parse(filepath)
+                    logger.info("%s is a valid %s logfile" % (filepath, file_extension))
+                elif file_extension == ".txt":
+                    fp.readline()
+                    logger.info("%s is a valid %s logfile" % (filepath, file_extension))
+                else:
+                    return False
+            except Exception as e:
+                logger.error("Not a valid format", e)
+                return False
+
+        return True
+
     def test_uuid_matches_stored_value(self):
         op_cli = ProviderFactory.get_provider("aws")
         store = op_cli.get_storage("keyvalue", 'partner_app_ids', logger=logger)
@@ -294,6 +330,8 @@ class TestApp(unittest.TestCase):
         self.assertTrue(self.manifestjson["uuid"] == store.get(app_name_slug))
 
     def check_params_in_log_query(self, query_string, location_text):
+        if not self.queryparams:
+            return True
         func = lambda r, x: r or x in query_string
         has_params_in_query = reduce(func, self.queryparams, False)
         if not has_params_in_query:
@@ -304,12 +342,14 @@ class TestApp(unittest.TestCase):
             else:
                 self.assertTrue(has_params_in_query, msg)
 
-    def check_params_in_metric_query(self, query_string, panel_name, dash_name):
+    def check_params_in_metric_query(self, query_string, location_text):
+        if not self.queryparams:
+            return True
         func = lambda r, x: r or x in query_string
         has_params_in_query = reduce(func, self.queryparams, False) or '#' in query_string
         if not has_params_in_query:
-            msg = "Metric Panel: %s in Dashboard: %s is not using %s" % (
-                panel_name, dash_name, ",".join(self.queryparams))
+            msg = "%s is not using %s" % (
+                location_text, ",".join(self.queryparams))
             if self.appname in EXCLUDED_APPS_WITHOUT_SC_PARAMS:
                 self.add_warning(msg)
             else:
@@ -351,7 +391,7 @@ class TestApp(unittest.TestCase):
             self.check_params_in_log_query(query_string, "Log Panel: %s in Dashboard: %s" % (panel_name, dash_name))
 
         for query_string, panel_name, dash_name in self.metric_queries:
-            self.check_params_in_metric_query(query_string, panel_name, dash_name)
+            self.check_params_in_metric_query(query_string, "Metric Panel: %s in Dashboard: %s" % (panel_name, dash_name))
 
         # for saved searches
         for query_string, search_name in self.saved_search_queries:
@@ -491,10 +531,10 @@ class TestClassicDashboardsV2(TestApp):
             if self.is_mew_board(dash):
                 if dash.get("rootPanel"):
                     dash["rootPanel"]["panels"] = [panel for panel in dash["rootPanel"]["panels"] if
-                                                   not (panel["panelType"] in ("TextPanel"))]
+                                                   not (panel["panelType"] in ("TextPanel", "EventsOfInterestScatterPanel"))]
 
                 else:
-                    dash["panels"] = [panel for panel in dash["panels"] if not (panel["panelType"] in ("TextPanel"))]
+                    dash["panels"] = [panel for panel in dash["panels"] if not (panel["panelType"] in ("TextPanel", "EventsOfInterestScatterPanel"))]
 
 
             else:
@@ -537,8 +577,7 @@ class TestClassicDashboardsV2(TestApp):
             else:
                 for panel in dash["panels"]:
                     self.assertTrue("timeRange" not in panel or panel["timeRange"] is None or self.matchanyterms(self.datetime_terms, json.dumps(panel["timeRange"])),
-                                    "Panel: %s in Dashboard: %s does not use relative time" % (
-                        panel.get("name"), dash.get("name")))
+                                    "Panel: %s in Dashboard: %s does not use relative time" % (panel.get("name"), dash.get("name")))
 
         for search in self.searches:
             self.assertTrue(search['search']["defaultTimeRange"].startswith("-"), "Saved Search: %s does not use relative time " % search["name"])
@@ -555,3 +594,33 @@ class TestClassicDashboardsV2(TestApp):
         for search in self.searches:
             if "searchSchedule" in search and search["searchSchedule"]:
                 self.add_warning("SavedSearch %s is scheduled with type %s" % (search['name'], search['searchSchedule']['notification']['taskType']))
+
+    def get_variable_queries(self, dashboards):
+        log_variable_queries = []
+        metric_variable_queries = []
+        for dash in dashboards:
+            if self.is_mew_board(dash):
+                for variable in dash.get("variables"):
+                    var_name = variable.get("name")
+                    definition = variable.get("sourceDefinition", {})
+                    if definition.get("variableSourceType") == "LogQueryVariableSourceDefinition":
+                        log_variable_queries.append((definition.get("query"), var_name, dash.get("name")))
+                    elif definition.get("variableSourceType") == "MetadataVariableSourceDefinition":
+                        metric_variable_queries.append((definition.get("filter"), var_name, dash.get("name")))
+
+        return log_variable_queries, metric_variable_queries
+
+    def test_all_params_replaced_in_dashboards(self):
+        super(TestClassicDashboardsV2, self).test_all_params_replaced_in_dashboards()
+        # apps having hardcoded params
+        if self.foldername in self.HARDCODED_PARAM_APPS:
+            return
+
+        log_variable_queries, metric_variable_queries = self.get_variable_queries(self.dashboards)
+
+        for query_string, variable_name, dash_name in log_variable_queries:
+            self.check_params_in_log_query(query_string, "Log variable: %s in Dashboard: %s" % (variable_name, dash_name))
+
+        for query_string, variable_name, dash_name in metric_variable_queries:
+            self.check_params_in_metric_query(query_string, "Metric variable: %s in Dashboard: %s" % (variable_name, dash_name))
+
